# coding: utf-8

"""
    Deep Lynx

    The construction of megaprojects has consistently demonstrated challenges for project managers in regard to meeting cost, schedule, and performance requirements. Megaproject construction challenges are common place within megaprojects with many active projects in the United States failing to meet cost and schedule efforts by significant margins. Currently, engineering teams operate in siloed tools and disparate teams where connections across design, procurement, and construction systems are translated manually or over brittle point-to-point integrations. The manual nature of data exchange increases the risk of silent errors in the reactor design, with each silent error cascading across the design. These cascading errors lead to uncontrollable risk during construction, resulting in significant delays and cost overruns. Deep Lynx allows for an integrated platform during design and operations of mega projects.  The Deep Lynx Core API delivers a few main features.  1. Provides a set of methods and endpoints for manipulating data in an object oriented database. This allows us to store complex datatypes as records and then to compile them into actual, modifiable objects at run-time. Users can store taxonomies or ontologies in a readable format.  2. Provides methods for storing and retrieving data in a graph database. This data is structured and validated against the aformentioned object oriented database before storage.  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from swagger_client.api_client import ApiClient


class AuthenticationApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def exchange_o_auth_token(self, **kwargs):  # noqa: E501
        """ExchangeOAuthToken  # noqa: E501

        Exchanges credentials for a JSON Web Token (JWT). Multiple authentication flows are supported, see Deep Lynx documentation for details.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.exchange_o_auth_token(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param TokenExchangeRequest body:
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.exchange_o_auth_token_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.exchange_o_auth_token_with_http_info(**kwargs)  # noqa: E501
            return data

    def exchange_o_auth_token_with_http_info(self, **kwargs):  # noqa: E501
        """ExchangeOAuthToken  # noqa: E501

        Exchanges credentials for a JSON Web Token (JWT). Multiple authentication flows are supported, see Deep Lynx documentation for details.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.exchange_o_auth_token_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param TokenExchangeRequest body:
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method exchange_o_auth_token" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['httpBearer']  # noqa: E501

        return self.api_client.call_api(
            '/oauth/exchange', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_containers_container_id_metatypes_metatype_id(self, container_id, metatype_id, **kwargs):  # noqa: E501
        """post-containers-container_id-metatypes-metatype_id  # noqa: E501

        Returns any errors associated with the intended properties or keys for a metatype or else the data itself if no errors are present.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_containers_container_id_metatypes_metatype_id(container_id, metatype_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container_id: (required)
        :param str metatype_id: (required)
        :param object body:
        :return: ValidateMetatypePropertiesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_containers_container_id_metatypes_metatype_id_with_http_info(container_id, metatype_id, **kwargs)  # noqa: E501
        else:
            (data) = self.post_containers_container_id_metatypes_metatype_id_with_http_info(container_id, metatype_id, **kwargs)  # noqa: E501
            return data

    def post_containers_container_id_metatypes_metatype_id_with_http_info(self, container_id, metatype_id, **kwargs):  # noqa: E501
        """post-containers-container_id-metatypes-metatype_id  # noqa: E501

        Returns any errors associated with the intended properties or keys for a metatype or else the data itself if no errors are present.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_containers_container_id_metatypes_metatype_id_with_http_info(container_id, metatype_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container_id: (required)
        :param str metatype_id: (required)
        :param object body:
        :return: ValidateMetatypePropertiesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['container_id', 'metatype_id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_containers_container_id_metatypes_metatype_id" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'container_id' is set
        if ('container_id' not in params or
                params['container_id'] is None):
            raise ValueError("Missing the required parameter `container_id` when calling `post_containers_container_id_metatypes_metatype_id`")  # noqa: E501
        # verify the required parameter 'metatype_id' is set
        if ('metatype_id' not in params or
                params['metatype_id'] is None):
            raise ValueError("Missing the required parameter `metatype_id` when calling `post_containers_container_id_metatypes_metatype_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'container_id' in params:
            path_params['container_id'] = params['container_id']  # noqa: E501
        if 'metatype_id' in params:
            path_params['metatype_id'] = params['metatype_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['text/plain'])  # noqa: E501

        # Authentication setting
        auth_settings = ['httpBearer']  # noqa: E501

        return self.api_client.call_api(
            '/containers/{container_id}/metatypes/{metatype_id}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ValidateMetatypePropertiesResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_rsa_cancel(self, **kwargs):  # noqa: E501
        """post-rsa-cancel  # noqa: E501

        Cancels an RSA authentication attempt  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_rsa_cancel(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RSACancelRequest body:
        :return: RSAResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_rsa_cancel_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.post_rsa_cancel_with_http_info(**kwargs)  # noqa: E501
            return data

    def post_rsa_cancel_with_http_info(self, **kwargs):  # noqa: E501
        """post-rsa-cancel  # noqa: E501

        Cancels an RSA authentication attempt  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_rsa_cancel_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RSACancelRequest body:
        :return: RSAResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_rsa_cancel" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['httpBearer']  # noqa: E501

        return self.api_client.call_api(
            '/rsa/cancel', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RSAResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_rsa_initialize(self, **kwargs):  # noqa: E501
        """post-rsa-initialize  # noqa: E501

        Used to begin (and optionally complete) an RSA authentication. Either a user's ID may be provided and the SecurID provided in a later `verify` request,  or else the user may provide both the user ID (`subjectName`) and `securID` at once to `initialize` to complete the authentication request.  The `securID` is the combination of the user's memorized token and 6 digit temporary RSA pin (with no spaces or characters between them).  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_rsa_initialize(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RSAInitRequest body:
        :return: RSAResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_rsa_initialize_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.post_rsa_initialize_with_http_info(**kwargs)  # noqa: E501
            return data

    def post_rsa_initialize_with_http_info(self, **kwargs):  # noqa: E501
        """post-rsa-initialize  # noqa: E501

        Used to begin (and optionally complete) an RSA authentication. Either a user's ID may be provided and the SecurID provided in a later `verify` request,  or else the user may provide both the user ID (`subjectName`) and `securID` at once to `initialize` to complete the authentication request.  The `securID` is the combination of the user's memorized token and 6 digit temporary RSA pin (with no spaces or characters between them).  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_rsa_initialize_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RSAInitRequest body:
        :return: RSAResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_rsa_initialize" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['httpBearer']  # noqa: E501

        return self.api_client.call_api(
            '/rsa/initialize', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RSAResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_rsa_status(self, **kwargs):  # noqa: E501
        """post-rsa-status  # noqa: E501

        Returns the status of an RSA authentication attempt  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_rsa_status(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RSAStatusRequest body:
        :return: RSAStatusResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_rsa_status_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.post_rsa_status_with_http_info(**kwargs)  # noqa: E501
            return data

    def post_rsa_status_with_http_info(self, **kwargs):  # noqa: E501
        """post-rsa-status  # noqa: E501

        Returns the status of an RSA authentication attempt  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_rsa_status_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RSAStatusRequest body:
        :return: RSAStatusResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_rsa_status" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['httpBearer']  # noqa: E501

        return self.api_client.call_api(
            '/rsa/status', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RSAStatusResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_rsa_verify(self, **kwargs):  # noqa: E501
        """post-rsa-verify  # noqa: E501

        Provides RSA with the user's SecurID to complete authentication  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_rsa_verify(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RSAVerifyRequest body:
        :return: RSAResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_rsa_verify_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.post_rsa_verify_with_http_info(**kwargs)  # noqa: E501
            return data

    def post_rsa_verify_with_http_info(self, **kwargs):  # noqa: E501
        """post-rsa-verify  # noqa: E501

        Provides RSA with the user's SecurID to complete authentication  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_rsa_verify_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RSAVerifyRequest body:
        :return: RSAResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_rsa_verify" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['httpBearer']  # noqa: E501

        return self.api_client.call_api(
            '/rsa/verify', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RSAResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def retrieve_o_auth_token(self, x_api_key, x_api_secret, **kwargs):  # noqa: E501
        """RetrieveOAuthToken  # noqa: E501

        Returns an OAuth token. The API key and secret must be supplied.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.retrieve_o_auth_token(x_api_key, x_api_secret, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str x_api_key: The API key (required)
        :param str x_api_secret: The API secret (required)
        :param str x_api_expiry: The API expiry date
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.retrieve_o_auth_token_with_http_info(x_api_key, x_api_secret, **kwargs)  # noqa: E501
        else:
            (data) = self.retrieve_o_auth_token_with_http_info(x_api_key, x_api_secret, **kwargs)  # noqa: E501
            return data

    def retrieve_o_auth_token_with_http_info(self, x_api_key, x_api_secret, **kwargs):  # noqa: E501
        """RetrieveOAuthToken  # noqa: E501

        Returns an OAuth token. The API key and secret must be supplied.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.retrieve_o_auth_token_with_http_info(x_api_key, x_api_secret, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str x_api_key: The API key (required)
        :param str x_api_secret: The API secret (required)
        :param str x_api_expiry: The API expiry date
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['x_api_key', 'x_api_secret', 'x_api_expiry']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method retrieve_o_auth_token" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'x_api_key' is set
        if ('x_api_key' not in params or
                params['x_api_key'] is None):
            raise ValueError("Missing the required parameter `x_api_key` when calling `retrieve_o_auth_token`")  # noqa: E501
        # verify the required parameter 'x_api_secret' is set
        if ('x_api_secret' not in params or
                params['x_api_secret'] is None):
            raise ValueError("Missing the required parameter `x_api_secret` when calling `retrieve_o_auth_token`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'x_api_key' in params:
            header_params['x-api-key'] = params['x_api_key']  # noqa: E501
        if 'x_api_secret' in params:
            header_params['x-api-secret'] = params['x_api_secret']  # noqa: E501
        if 'x_api_expiry' in params:
            header_params['x-api-expiry'] = params['x_api_expiry']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/plain'])  # noqa: E501

        # Authentication setting
        auth_settings = ['httpBearer']  # noqa: E501

        return self.api_client.call_api(
            '/oauth/token', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Deep Lynx

    The construction of megaprojects has consistently demonstrated challenges for project managers in regard to meeting cost, schedule, and performance requirements. Megaproject construction challenges are common place within megaprojects with many active projects in the United States failing to meet cost and schedule efforts by significant margins. Currently, engineering teams operate in siloed tools and disparate teams where connections across design, procurement, and construction systems are translated manually or over brittle point-to-point integrations. The manual nature of data exchange increases the risk of silent errors in the reactor design, with each silent error cascading across the design. These cascading errors lead to uncontrollable risk during construction, resulting in significant delays and cost overruns. Deep Lynx allows for an integrated platform during design and operations of mega projects.  The Deep Lynx Core API delivers a few main features.  1. Provides a set of methods and endpoints for manipulating data in an object oriented database. This allows us to store complex datatypes as records and then to compile them into actual, modifiable objects at run-time. Users can store taxonomies or ontologies in a readable format.  2. Provides methods for storing and retrieving data in a graph database. This data is structured and validated against the aformentioned object oriented database before storage.  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class RSAResponseValueChallengeMethodsPrompt(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'prompt_resource_id': 'str',
        'default_text': 'str',
        'format_regex': 'str',
        'default_value': 'str',
        'value_being_defined': 'bool',
        'sensitive': 'bool',
        'min_length': 'str',
        'max_length': 'str',
        'prompt_args': 'list[str]'
    }

    attribute_map = {
        'prompt_resource_id': 'promptResourceId',
        'default_text': 'defaultText',
        'format_regex': 'formatRegex',
        'default_value': 'defaultValue',
        'value_being_defined': 'valueBeingDefined',
        'sensitive': 'sensitive',
        'min_length': 'minLength',
        'max_length': 'maxLength',
        'prompt_args': 'promptArgs'
    }

    def __init__(self, prompt_resource_id=None, default_text=None, format_regex=None, default_value=None, value_being_defined=None, sensitive=None, min_length=None, max_length=None, prompt_args=None):  # noqa: E501
        """RSAResponseValueChallengeMethodsPrompt - a model defined in Swagger"""  # noqa: E501
        self._prompt_resource_id = None
        self._default_text = None
        self._format_regex = None
        self._default_value = None
        self._value_being_defined = None
        self._sensitive = None
        self._min_length = None
        self._max_length = None
        self._prompt_args = None
        self.discriminator = None
        if prompt_resource_id is not None:
            self.prompt_resource_id = prompt_resource_id
        if default_text is not None:
            self.default_text = default_text
        if format_regex is not None:
            self.format_regex = format_regex
        if default_value is not None:
            self.default_value = default_value
        if value_being_defined is not None:
            self.value_being_defined = value_being_defined
        if sensitive is not None:
            self.sensitive = sensitive
        if min_length is not None:
            self.min_length = min_length
        if max_length is not None:
            self.max_length = max_length
        if prompt_args is not None:
            self.prompt_args = prompt_args

    @property
    def prompt_resource_id(self):
        """Gets the prompt_resource_id of this RSAResponseValueChallengeMethodsPrompt.  # noqa: E501


        :return: The prompt_resource_id of this RSAResponseValueChallengeMethodsPrompt.  # noqa: E501
        :rtype: str
        """
        return self._prompt_resource_id

    @prompt_resource_id.setter
    def prompt_resource_id(self, prompt_resource_id):
        """Sets the prompt_resource_id of this RSAResponseValueChallengeMethodsPrompt.


        :param prompt_resource_id: The prompt_resource_id of this RSAResponseValueChallengeMethodsPrompt.  # noqa: E501
        :type: str
        """

        self._prompt_resource_id = prompt_resource_id

    @property
    def default_text(self):
        """Gets the default_text of this RSAResponseValueChallengeMethodsPrompt.  # noqa: E501


        :return: The default_text of this RSAResponseValueChallengeMethodsPrompt.  # noqa: E501
        :rtype: str
        """
        return self._default_text

    @default_text.setter
    def default_text(self, default_text):
        """Sets the default_text of this RSAResponseValueChallengeMethodsPrompt.


        :param default_text: The default_text of this RSAResponseValueChallengeMethodsPrompt.  # noqa: E501
        :type: str
        """

        self._default_text = default_text

    @property
    def format_regex(self):
        """Gets the format_regex of this RSAResponseValueChallengeMethodsPrompt.  # noqa: E501


        :return: The format_regex of this RSAResponseValueChallengeMethodsPrompt.  # noqa: E501
        :rtype: str
        """
        return self._format_regex

    @format_regex.setter
    def format_regex(self, format_regex):
        """Sets the format_regex of this RSAResponseValueChallengeMethodsPrompt.


        :param format_regex: The format_regex of this RSAResponseValueChallengeMethodsPrompt.  # noqa: E501
        :type: str
        """

        self._format_regex = format_regex

    @property
    def default_value(self):
        """Gets the default_value of this RSAResponseValueChallengeMethodsPrompt.  # noqa: E501


        :return: The default_value of this RSAResponseValueChallengeMethodsPrompt.  # noqa: E501
        :rtype: str
        """
        return self._default_value

    @default_value.setter
    def default_value(self, default_value):
        """Sets the default_value of this RSAResponseValueChallengeMethodsPrompt.


        :param default_value: The default_value of this RSAResponseValueChallengeMethodsPrompt.  # noqa: E501
        :type: str
        """

        self._default_value = default_value

    @property
    def value_being_defined(self):
        """Gets the value_being_defined of this RSAResponseValueChallengeMethodsPrompt.  # noqa: E501


        :return: The value_being_defined of this RSAResponseValueChallengeMethodsPrompt.  # noqa: E501
        :rtype: bool
        """
        return self._value_being_defined

    @value_being_defined.setter
    def value_being_defined(self, value_being_defined):
        """Sets the value_being_defined of this RSAResponseValueChallengeMethodsPrompt.


        :param value_being_defined: The value_being_defined of this RSAResponseValueChallengeMethodsPrompt.  # noqa: E501
        :type: bool
        """

        self._value_being_defined = value_being_defined

    @property
    def sensitive(self):
        """Gets the sensitive of this RSAResponseValueChallengeMethodsPrompt.  # noqa: E501


        :return: The sensitive of this RSAResponseValueChallengeMethodsPrompt.  # noqa: E501
        :rtype: bool
        """
        return self._sensitive

    @sensitive.setter
    def sensitive(self, sensitive):
        """Sets the sensitive of this RSAResponseValueChallengeMethodsPrompt.


        :param sensitive: The sensitive of this RSAResponseValueChallengeMethodsPrompt.  # noqa: E501
        :type: bool
        """

        self._sensitive = sensitive

    @property
    def min_length(self):
        """Gets the min_length of this RSAResponseValueChallengeMethodsPrompt.  # noqa: E501


        :return: The min_length of this RSAResponseValueChallengeMethodsPrompt.  # noqa: E501
        :rtype: str
        """
        return self._min_length

    @min_length.setter
    def min_length(self, min_length):
        """Sets the min_length of this RSAResponseValueChallengeMethodsPrompt.


        :param min_length: The min_length of this RSAResponseValueChallengeMethodsPrompt.  # noqa: E501
        :type: str
        """

        self._min_length = min_length

    @property
    def max_length(self):
        """Gets the max_length of this RSAResponseValueChallengeMethodsPrompt.  # noqa: E501


        :return: The max_length of this RSAResponseValueChallengeMethodsPrompt.  # noqa: E501
        :rtype: str
        """
        return self._max_length

    @max_length.setter
    def max_length(self, max_length):
        """Sets the max_length of this RSAResponseValueChallengeMethodsPrompt.


        :param max_length: The max_length of this RSAResponseValueChallengeMethodsPrompt.  # noqa: E501
        :type: str
        """

        self._max_length = max_length

    @property
    def prompt_args(self):
        """Gets the prompt_args of this RSAResponseValueChallengeMethodsPrompt.  # noqa: E501


        :return: The prompt_args of this RSAResponseValueChallengeMethodsPrompt.  # noqa: E501
        :rtype: list[str]
        """
        return self._prompt_args

    @prompt_args.setter
    def prompt_args(self, prompt_args):
        """Sets the prompt_args of this RSAResponseValueChallengeMethodsPrompt.


        :param prompt_args: The prompt_args of this RSAResponseValueChallengeMethodsPrompt.  # noqa: E501
        :type: list[str]
        """

        self._prompt_args = prompt_args

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RSAResponseValueChallengeMethodsPrompt, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RSAResponseValueChallengeMethodsPrompt):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Deep Lynx

    The construction of megaprojects has consistently demonstrated challenges for project managers in regard to meeting cost, schedule, and performance requirements. Megaproject construction challenges are common place within megaprojects with many active projects in the United States failing to meet cost and schedule efforts by significant margins. Currently, engineering teams operate in siloed tools and disparate teams where connections across design, procurement, and construction systems are translated manually or over brittle point-to-point integrations. The manual nature of data exchange increases the risk of silent errors in the reactor design, with each silent error cascading across the design. These cascading errors lead to uncontrollable risk during construction, resulting in significant delays and cost overruns. Deep Lynx allows for an integrated platform during design and operations of mega projects.  The Deep Lynx Core API delivers a few main features.  1. Provides a set of methods and endpoints for manipulating data in an object oriented database. This allows us to store complex datatypes as records and then to compile them into actual, modifiable objects at run-time. Users can store taxonomies or ontologies in a readable format.  2. Provides methods for storing and retrieving data in a graph database. This data is structured and validated against the aformentioned object oriented database before storage.  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class TypeMapping(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'active': 'bool',
        'id': 'str',
        'container_id': 'str',
        'data_source_id': 'str',
        'shape_hash': 'str',
        'created_at': 'str',
        'modified_at': 'str',
        'sample_payload': 'object',
        'created_by': 'str',
        'modified_by': 'str',
        'transformations': 'list[Transformation]',
        'resulting_metatype_name': 'str',
        'resulting_metatype_relationship_name': 'str'
    }

    attribute_map = {
        'active': 'active',
        'id': 'id',
        'container_id': 'container_id',
        'data_source_id': 'data_source_id',
        'shape_hash': 'shape_hash',
        'created_at': 'created_at',
        'modified_at': 'modified_at',
        'sample_payload': 'sample_payload',
        'created_by': 'created_by',
        'modified_by': 'modified_by',
        'transformations': 'transformations',
        'resulting_metatype_name': 'resulting_metatype_name',
        'resulting_metatype_relationship_name': 'resulting_metatype_relationship_name'
    }

    def __init__(self, active=None, id=None, container_id=None, data_source_id=None, shape_hash=None, created_at=None, modified_at=None, sample_payload=None, created_by=None, modified_by=None, transformations=None, resulting_metatype_name=None, resulting_metatype_relationship_name=None):  # noqa: E501
        """TypeMapping - a model defined in Swagger"""  # noqa: E501
        self._active = None
        self._id = None
        self._container_id = None
        self._data_source_id = None
        self._shape_hash = None
        self._created_at = None
        self._modified_at = None
        self._sample_payload = None
        self._created_by = None
        self._modified_by = None
        self._transformations = None
        self._resulting_metatype_name = None
        self._resulting_metatype_relationship_name = None
        self.discriminator = None
        self.active = active
        if id is not None:
            self.id = id
        if container_id is not None:
            self.container_id = container_id
        if data_source_id is not None:
            self.data_source_id = data_source_id
        self.shape_hash = shape_hash
        if created_at is not None:
            self.created_at = created_at
        if modified_at is not None:
            self.modified_at = modified_at
        self.sample_payload = sample_payload
        if created_by is not None:
            self.created_by = created_by
        if modified_by is not None:
            self.modified_by = modified_by
        if transformations is not None:
            self.transformations = transformations
        if resulting_metatype_name is not None:
            self.resulting_metatype_name = resulting_metatype_name
        if resulting_metatype_relationship_name is not None:
            self.resulting_metatype_relationship_name = resulting_metatype_relationship_name

    @property
    def active(self):
        """Gets the active of this TypeMapping.  # noqa: E501


        :return: The active of this TypeMapping.  # noqa: E501
        :rtype: bool
        """
        return self._active

    @active.setter
    def active(self, active):
        """Sets the active of this TypeMapping.


        :param active: The active of this TypeMapping.  # noqa: E501
        :type: bool
        """
        if active is None:
            raise ValueError("Invalid value for `active`, must not be `None`")  # noqa: E501

        self._active = active

    @property
    def id(self):
        """Gets the id of this TypeMapping.  # noqa: E501


        :return: The id of this TypeMapping.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this TypeMapping.


        :param id: The id of this TypeMapping.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def container_id(self):
        """Gets the container_id of this TypeMapping.  # noqa: E501


        :return: The container_id of this TypeMapping.  # noqa: E501
        :rtype: str
        """
        return self._container_id

    @container_id.setter
    def container_id(self, container_id):
        """Sets the container_id of this TypeMapping.


        :param container_id: The container_id of this TypeMapping.  # noqa: E501
        :type: str
        """

        self._container_id = container_id

    @property
    def data_source_id(self):
        """Gets the data_source_id of this TypeMapping.  # noqa: E501


        :return: The data_source_id of this TypeMapping.  # noqa: E501
        :rtype: str
        """
        return self._data_source_id

    @data_source_id.setter
    def data_source_id(self, data_source_id):
        """Sets the data_source_id of this TypeMapping.


        :param data_source_id: The data_source_id of this TypeMapping.  # noqa: E501
        :type: str
        """

        self._data_source_id = data_source_id

    @property
    def shape_hash(self):
        """Gets the shape_hash of this TypeMapping.  # noqa: E501


        :return: The shape_hash of this TypeMapping.  # noqa: E501
        :rtype: str
        """
        return self._shape_hash

    @shape_hash.setter
    def shape_hash(self, shape_hash):
        """Sets the shape_hash of this TypeMapping.


        :param shape_hash: The shape_hash of this TypeMapping.  # noqa: E501
        :type: str
        """
        if shape_hash is None:
            raise ValueError("Invalid value for `shape_hash`, must not be `None`")  # noqa: E501

        self._shape_hash = shape_hash

    @property
    def created_at(self):
        """Gets the created_at of this TypeMapping.  # noqa: E501


        :return: The created_at of this TypeMapping.  # noqa: E501
        :rtype: str
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this TypeMapping.


        :param created_at: The created_at of this TypeMapping.  # noqa: E501
        :type: str
        """

        self._created_at = created_at

    @property
    def modified_at(self):
        """Gets the modified_at of this TypeMapping.  # noqa: E501


        :return: The modified_at of this TypeMapping.  # noqa: E501
        :rtype: str
        """
        return self._modified_at

    @modified_at.setter
    def modified_at(self, modified_at):
        """Sets the modified_at of this TypeMapping.


        :param modified_at: The modified_at of this TypeMapping.  # noqa: E501
        :type: str
        """

        self._modified_at = modified_at

    @property
    def sample_payload(self):
        """Gets the sample_payload of this TypeMapping.  # noqa: E501


        :return: The sample_payload of this TypeMapping.  # noqa: E501
        :rtype: object
        """
        return self._sample_payload

    @sample_payload.setter
    def sample_payload(self, sample_payload):
        """Sets the sample_payload of this TypeMapping.


        :param sample_payload: The sample_payload of this TypeMapping.  # noqa: E501
        :type: object
        """
        if sample_payload is None:
            raise ValueError("Invalid value for `sample_payload`, must not be `None`")  # noqa: E501

        self._sample_payload = sample_payload

    @property
    def created_by(self):
        """Gets the created_by of this TypeMapping.  # noqa: E501


        :return: The created_by of this TypeMapping.  # noqa: E501
        :rtype: str
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this TypeMapping.


        :param created_by: The created_by of this TypeMapping.  # noqa: E501
        :type: str
        """

        self._created_by = created_by

    @property
    def modified_by(self):
        """Gets the modified_by of this TypeMapping.  # noqa: E501


        :return: The modified_by of this TypeMapping.  # noqa: E501
        :rtype: str
        """
        return self._modified_by

    @modified_by.setter
    def modified_by(self, modified_by):
        """Sets the modified_by of this TypeMapping.


        :param modified_by: The modified_by of this TypeMapping.  # noqa: E501
        :type: str
        """

        self._modified_by = modified_by

    @property
    def transformations(self):
        """Gets the transformations of this TypeMapping.  # noqa: E501


        :return: The transformations of this TypeMapping.  # noqa: E501
        :rtype: list[Transformation]
        """
        return self._transformations

    @transformations.setter
    def transformations(self, transformations):
        """Sets the transformations of this TypeMapping.


        :param transformations: The transformations of this TypeMapping.  # noqa: E501
        :type: list[Transformation]
        """

        self._transformations = transformations

    @property
    def resulting_metatype_name(self):
        """Gets the resulting_metatype_name of this TypeMapping.  # noqa: E501


        :return: The resulting_metatype_name of this TypeMapping.  # noqa: E501
        :rtype: str
        """
        return self._resulting_metatype_name

    @resulting_metatype_name.setter
    def resulting_metatype_name(self, resulting_metatype_name):
        """Sets the resulting_metatype_name of this TypeMapping.


        :param resulting_metatype_name: The resulting_metatype_name of this TypeMapping.  # noqa: E501
        :type: str
        """

        self._resulting_metatype_name = resulting_metatype_name

    @property
    def resulting_metatype_relationship_name(self):
        """Gets the resulting_metatype_relationship_name of this TypeMapping.  # noqa: E501


        :return: The resulting_metatype_relationship_name of this TypeMapping.  # noqa: E501
        :rtype: str
        """
        return self._resulting_metatype_relationship_name

    @resulting_metatype_relationship_name.setter
    def resulting_metatype_relationship_name(self, resulting_metatype_relationship_name):
        """Sets the resulting_metatype_relationship_name of this TypeMapping.


        :param resulting_metatype_relationship_name: The resulting_metatype_relationship_name of this TypeMapping.  # noqa: E501
        :type: str
        """

        self._resulting_metatype_relationship_name = resulting_metatype_relationship_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TypeMapping, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TypeMapping):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Deep Lynx

    The construction of megaprojects has consistently demonstrated challenges for project managers in regard to meeting cost, schedule, and performance requirements. Megaproject construction challenges are common place within megaprojects with many active projects in the United States failing to meet cost and schedule efforts by significant margins. Currently, engineering teams operate in siloed tools and disparate teams where connections across design, procurement, and construction systems are translated manually or over brittle point-to-point integrations. The manual nature of data exchange increases the risk of silent errors in the reactor design, with each silent error cascading across the design. These cascading errors lead to uncontrollable risk during construction, resulting in significant delays and cost overruns. Deep Lynx allows for an integrated platform during design and operations of mega projects.  The Deep Lynx Core API delivers a few main features.  1. Provides a set of methods and endpoints for manipulating data in an object oriented database. This allows us to store complex datatypes as records and then to compile them into actual, modifiable objects at run-time. Users can store taxonomies or ontologies in a readable format.  2. Provides methods for storing and retrieving data in a graph database. This data is structured and validated against the aformentioned object oriented database before storage.  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class MetatypeKey(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'description': 'str',
        'property_name': 'str',
        'data_type': 'str',
        'required': 'bool',
        'metatype_id': 'str',
        'id': 'str',
        'options': 'list[object]',
        'default_value': 'str',
        'archived': 'bool',
        'created_at': 'str',
        'modified_at': 'str',
        'created_by': 'str',
        'modified_by': 'str',
        'validation': 'KeyValidation'
    }

    attribute_map = {
        'name': 'name',
        'description': 'description',
        'property_name': 'property_name',
        'data_type': 'data_type',
        'required': 'required',
        'metatype_id': 'metatype_id',
        'id': 'id',
        'options': 'options',
        'default_value': 'default_value',
        'archived': 'archived',
        'created_at': 'created_at',
        'modified_at': 'modified_at',
        'created_by': 'created_by',
        'modified_by': 'modified_by',
        'validation': 'validation'
    }

    def __init__(self, name=None, description=None, property_name=None, data_type=None, required=None, metatype_id=None, id=None, options=None, default_value=None, archived=None, created_at=None, modified_at=None, created_by=None, modified_by=None, validation=None):  # noqa: E501
        """MetatypeKey - a model defined in Swagger"""  # noqa: E501
        self._name = None
        self._description = None
        self._property_name = None
        self._data_type = None
        self._required = None
        self._metatype_id = None
        self._id = None
        self._options = None
        self._default_value = None
        self._archived = None
        self._created_at = None
        self._modified_at = None
        self._created_by = None
        self._modified_by = None
        self._validation = None
        self.discriminator = None
        self.name = name
        self.description = description
        if property_name is not None:
            self.property_name = property_name
        self.data_type = data_type
        if required is not None:
            self.required = required
        self.metatype_id = metatype_id
        if id is not None:
            self.id = id
        if options is not None:
            self.options = options
        if default_value is not None:
            self.default_value = default_value
        if archived is not None:
            self.archived = archived
        if created_at is not None:
            self.created_at = created_at
        if modified_at is not None:
            self.modified_at = modified_at
        if created_by is not None:
            self.created_by = created_by
        if modified_by is not None:
            self.modified_by = modified_by
        if validation is not None:
            self.validation = validation

    @property
    def name(self):
        """Gets the name of this MetatypeKey.  # noqa: E501


        :return: The name of this MetatypeKey.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this MetatypeKey.


        :param name: The name of this MetatypeKey.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def description(self):
        """Gets the description of this MetatypeKey.  # noqa: E501


        :return: The description of this MetatypeKey.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this MetatypeKey.


        :param description: The description of this MetatypeKey.  # noqa: E501
        :type: str
        """
        if description is None:
            raise ValueError("Invalid value for `description`, must not be `None`")  # noqa: E501

        self._description = description

    @property
    def property_name(self):
        """Gets the property_name of this MetatypeKey.  # noqa: E501


        :return: The property_name of this MetatypeKey.  # noqa: E501
        :rtype: str
        """
        return self._property_name

    @property_name.setter
    def property_name(self, property_name):
        """Sets the property_name of this MetatypeKey.


        :param property_name: The property_name of this MetatypeKey.  # noqa: E501
        :type: str
        """

        self._property_name = property_name

    @property
    def data_type(self):
        """Gets the data_type of this MetatypeKey.  # noqa: E501


        :return: The data_type of this MetatypeKey.  # noqa: E501
        :rtype: str
        """
        return self._data_type

    @data_type.setter
    def data_type(self, data_type):
        """Sets the data_type of this MetatypeKey.


        :param data_type: The data_type of this MetatypeKey.  # noqa: E501
        :type: str
        """
        if data_type is None:
            raise ValueError("Invalid value for `data_type`, must not be `None`")  # noqa: E501

        self._data_type = data_type

    @property
    def required(self):
        """Gets the required of this MetatypeKey.  # noqa: E501


        :return: The required of this MetatypeKey.  # noqa: E501
        :rtype: bool
        """
        return self._required

    @required.setter
    def required(self, required):
        """Sets the required of this MetatypeKey.


        :param required: The required of this MetatypeKey.  # noqa: E501
        :type: bool
        """

        self._required = required

    @property
    def metatype_id(self):
        """Gets the metatype_id of this MetatypeKey.  # noqa: E501


        :return: The metatype_id of this MetatypeKey.  # noqa: E501
        :rtype: str
        """
        return self._metatype_id

    @metatype_id.setter
    def metatype_id(self, metatype_id):
        """Sets the metatype_id of this MetatypeKey.


        :param metatype_id: The metatype_id of this MetatypeKey.  # noqa: E501
        :type: str
        """
        if metatype_id is None:
            raise ValueError("Invalid value for `metatype_id`, must not be `None`")  # noqa: E501

        self._metatype_id = metatype_id

    @property
    def id(self):
        """Gets the id of this MetatypeKey.  # noqa: E501


        :return: The id of this MetatypeKey.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this MetatypeKey.


        :param id: The id of this MetatypeKey.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def options(self):
        """Gets the options of this MetatypeKey.  # noqa: E501


        :return: The options of this MetatypeKey.  # noqa: E501
        :rtype: list[object]
        """
        return self._options

    @options.setter
    def options(self, options):
        """Sets the options of this MetatypeKey.


        :param options: The options of this MetatypeKey.  # noqa: E501
        :type: list[object]
        """

        self._options = options

    @property
    def default_value(self):
        """Gets the default_value of this MetatypeKey.  # noqa: E501


        :return: The default_value of this MetatypeKey.  # noqa: E501
        :rtype: str
        """
        return self._default_value

    @default_value.setter
    def default_value(self, default_value):
        """Sets the default_value of this MetatypeKey.


        :param default_value: The default_value of this MetatypeKey.  # noqa: E501
        :type: str
        """

        self._default_value = default_value

    @property
    def archived(self):
        """Gets the archived of this MetatypeKey.  # noqa: E501


        :return: The archived of this MetatypeKey.  # noqa: E501
        :rtype: bool
        """
        return self._archived

    @archived.setter
    def archived(self, archived):
        """Sets the archived of this MetatypeKey.


        :param archived: The archived of this MetatypeKey.  # noqa: E501
        :type: bool
        """

        self._archived = archived

    @property
    def created_at(self):
        """Gets the created_at of this MetatypeKey.  # noqa: E501


        :return: The created_at of this MetatypeKey.  # noqa: E501
        :rtype: str
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this MetatypeKey.


        :param created_at: The created_at of this MetatypeKey.  # noqa: E501
        :type: str
        """

        self._created_at = created_at

    @property
    def modified_at(self):
        """Gets the modified_at of this MetatypeKey.  # noqa: E501


        :return: The modified_at of this MetatypeKey.  # noqa: E501
        :rtype: str
        """
        return self._modified_at

    @modified_at.setter
    def modified_at(self, modified_at):
        """Sets the modified_at of this MetatypeKey.


        :param modified_at: The modified_at of this MetatypeKey.  # noqa: E501
        :type: str
        """

        self._modified_at = modified_at

    @property
    def created_by(self):
        """Gets the created_by of this MetatypeKey.  # noqa: E501


        :return: The created_by of this MetatypeKey.  # noqa: E501
        :rtype: str
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this MetatypeKey.


        :param created_by: The created_by of this MetatypeKey.  # noqa: E501
        :type: str
        """

        self._created_by = created_by

    @property
    def modified_by(self):
        """Gets the modified_by of this MetatypeKey.  # noqa: E501


        :return: The modified_by of this MetatypeKey.  # noqa: E501
        :rtype: str
        """
        return self._modified_by

    @modified_by.setter
    def modified_by(self, modified_by):
        """Sets the modified_by of this MetatypeKey.


        :param modified_by: The modified_by of this MetatypeKey.  # noqa: E501
        :type: str
        """

        self._modified_by = modified_by

    @property
    def validation(self):
        """Gets the validation of this MetatypeKey.  # noqa: E501


        :return: The validation of this MetatypeKey.  # noqa: E501
        :rtype: KeyValidation
        """
        return self._validation

    @validation.setter
    def validation(self, validation):
        """Sets the validation of this MetatypeKey.


        :param validation: The validation of this MetatypeKey.  # noqa: E501
        :type: KeyValidation
        """

        self._validation = validation

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(MetatypeKey, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MetatypeKey):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Deep Lynx

    The construction of megaprojects has consistently demonstrated challenges for project managers in regard to meeting cost, schedule, and performance requirements. Megaproject construction challenges are common place within megaprojects with many active projects in the United States failing to meet cost and schedule efforts by significant margins. Currently, engineering teams operate in siloed tools and disparate teams where connections across design, procurement, and construction systems are translated manually or over brittle point-to-point integrations. The manual nature of data exchange increases the risk of silent errors in the reactor design, with each silent error cascading across the design. These cascading errors lead to uncontrollable risk during construction, resulting in significant delays and cost overruns. Deep Lynx allows for an integrated platform during design and operations of mega projects.  The Deep Lynx Core API delivers a few main features.  1. Provides a set of methods and endpoints for manipulating data in an object oriented database. This allows us to store complex datatypes as records and then to compile them into actual, modifiable objects at run-time. Users can store taxonomies or ontologies in a readable format.  2. Provides methods for storing and retrieving data in a graph database. This data is structured and validated against the aformentioned object oriented database before storage.  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class Edge(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'properties': 'object',
        'id': 'str',
        'container_id': 'str',
        'relationship_pair_id': 'str',
        'graph_id': 'str',
        'origin_node_id': 'str',
        'destination_node_id': 'str',
        'archived': 'bool',
        'created_at': 'str',
        'modified_at': 'str',
        'original_data_id': 'str',
        'data_source_id': 'str',
        'origin_node_original_id': 'str',
        'destination_node_original_id': 'str',
        'deleted_at': 'str',
        'data_staging_id': 'float',
        'import_data_id': 'str',
        'type_mapping_transformation_id': 'str',
        'composite_original_id': 'object',
        'origin_node_composite_original_id': 'str',
        'destination_node_composite_original_id': 'str',
        'created_by': 'str',
        'modified_by': 'str'
    }

    attribute_map = {
        'properties': 'properties',
        'id': 'id',
        'container_id': 'container_id',
        'relationship_pair_id': 'relationship_pair_id',
        'graph_id': 'graph_id',
        'origin_node_id': 'origin_node_id',
        'destination_node_id': 'destination_node_id',
        'archived': 'archived',
        'created_at': 'created_at',
        'modified_at': 'modified_at',
        'original_data_id': 'original_data_id',
        'data_source_id': 'data_source_id',
        'origin_node_original_id': 'origin_node_original_id',
        'destination_node_original_id': 'destination_node_original_id',
        'deleted_at': 'deleted_at',
        'data_staging_id': 'data_staging_id',
        'import_data_id': 'import_data_id',
        'type_mapping_transformation_id': 'type_mapping_transformation_id',
        'composite_original_id': 'composite_original_id',
        'origin_node_composite_original_id': 'origin_node_composite_original_id',
        'destination_node_composite_original_id': 'destination_node_composite_original_id',
        'created_by': 'created_by',
        'modified_by': 'modified_by'
    }

    def __init__(self, properties=None, id=None, container_id=None, relationship_pair_id=None, graph_id=None, origin_node_id=None, destination_node_id=None, archived=None, created_at=None, modified_at=None, original_data_id=None, data_source_id=None, origin_node_original_id=None, destination_node_original_id=None, deleted_at=None, data_staging_id=None, import_data_id=None, type_mapping_transformation_id=None, composite_original_id=None, origin_node_composite_original_id=None, destination_node_composite_original_id=None, created_by=None, modified_by=None):  # noqa: E501
        """Edge - a model defined in Swagger"""  # noqa: E501
        self._properties = None
        self._id = None
        self._container_id = None
        self._relationship_pair_id = None
        self._graph_id = None
        self._origin_node_id = None
        self._destination_node_id = None
        self._archived = None
        self._created_at = None
        self._modified_at = None
        self._original_data_id = None
        self._data_source_id = None
        self._origin_node_original_id = None
        self._destination_node_original_id = None
        self._deleted_at = None
        self._data_staging_id = None
        self._import_data_id = None
        self._type_mapping_transformation_id = None
        self._composite_original_id = None
        self._origin_node_composite_original_id = None
        self._destination_node_composite_original_id = None
        self._created_by = None
        self._modified_by = None
        self.discriminator = None
        self.properties = properties
        self.id = id
        self.container_id = container_id
        self.relationship_pair_id = relationship_pair_id
        self.graph_id = graph_id
        self.origin_node_id = origin_node_id
        self.destination_node_id = destination_node_id
        self.archived = archived
        self.created_at = created_at
        if modified_at is not None:
            self.modified_at = modified_at
        if original_data_id is not None:
            self.original_data_id = original_data_id
        self.data_source_id = data_source_id
        self.origin_node_original_id = origin_node_original_id
        self.destination_node_original_id = destination_node_original_id
        if deleted_at is not None:
            self.deleted_at = deleted_at
        self.data_staging_id = data_staging_id
        self.import_data_id = import_data_id
        self.type_mapping_transformation_id = type_mapping_transformation_id
        if composite_original_id is not None:
            self.composite_original_id = composite_original_id
        self.origin_node_composite_original_id = origin_node_composite_original_id
        self.destination_node_composite_original_id = destination_node_composite_original_id
        self.created_by = created_by
        self.modified_by = modified_by

    @property
    def properties(self):
        """Gets the properties of this Edge.  # noqa: E501


        :return: The properties of this Edge.  # noqa: E501
        :rtype: object
        """
        return self._properties

    @properties.setter
    def properties(self, properties):
        """Sets the properties of this Edge.


        :param properties: The properties of this Edge.  # noqa: E501
        :type: object
        """
        if properties is None:
            raise ValueError("Invalid value for `properties`, must not be `None`")  # noqa: E501

        self._properties = properties

    @property
    def id(self):
        """Gets the id of this Edge.  # noqa: E501


        :return: The id of this Edge.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Edge.


        :param id: The id of this Edge.  # noqa: E501
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def container_id(self):
        """Gets the container_id of this Edge.  # noqa: E501


        :return: The container_id of this Edge.  # noqa: E501
        :rtype: str
        """
        return self._container_id

    @container_id.setter
    def container_id(self, container_id):
        """Sets the container_id of this Edge.


        :param container_id: The container_id of this Edge.  # noqa: E501
        :type: str
        """
        if container_id is None:
            raise ValueError("Invalid value for `container_id`, must not be `None`")  # noqa: E501

        self._container_id = container_id

    @property
    def relationship_pair_id(self):
        """Gets the relationship_pair_id of this Edge.  # noqa: E501


        :return: The relationship_pair_id of this Edge.  # noqa: E501
        :rtype: str
        """
        return self._relationship_pair_id

    @relationship_pair_id.setter
    def relationship_pair_id(self, relationship_pair_id):
        """Sets the relationship_pair_id of this Edge.


        :param relationship_pair_id: The relationship_pair_id of this Edge.  # noqa: E501
        :type: str
        """
        if relationship_pair_id is None:
            raise ValueError("Invalid value for `relationship_pair_id`, must not be `None`")  # noqa: E501

        self._relationship_pair_id = relationship_pair_id

    @property
    def graph_id(self):
        """Gets the graph_id of this Edge.  # noqa: E501


        :return: The graph_id of this Edge.  # noqa: E501
        :rtype: str
        """
        return self._graph_id

    @graph_id.setter
    def graph_id(self, graph_id):
        """Sets the graph_id of this Edge.


        :param graph_id: The graph_id of this Edge.  # noqa: E501
        :type: str
        """
        if graph_id is None:
            raise ValueError("Invalid value for `graph_id`, must not be `None`")  # noqa: E501

        self._graph_id = graph_id

    @property
    def origin_node_id(self):
        """Gets the origin_node_id of this Edge.  # noqa: E501


        :return: The origin_node_id of this Edge.  # noqa: E501
        :rtype: str
        """
        return self._origin_node_id

    @origin_node_id.setter
    def origin_node_id(self, origin_node_id):
        """Sets the origin_node_id of this Edge.


        :param origin_node_id: The origin_node_id of this Edge.  # noqa: E501
        :type: str
        """
        if origin_node_id is None:
            raise ValueError("Invalid value for `origin_node_id`, must not be `None`")  # noqa: E501

        self._origin_node_id = origin_node_id

    @property
    def destination_node_id(self):
        """Gets the destination_node_id of this Edge.  # noqa: E501


        :return: The destination_node_id of this Edge.  # noqa: E501
        :rtype: str
        """
        return self._destination_node_id

    @destination_node_id.setter
    def destination_node_id(self, destination_node_id):
        """Sets the destination_node_id of this Edge.


        :param destination_node_id: The destination_node_id of this Edge.  # noqa: E501
        :type: str
        """
        if destination_node_id is None:
            raise ValueError("Invalid value for `destination_node_id`, must not be `None`")  # noqa: E501

        self._destination_node_id = destination_node_id

    @property
    def archived(self):
        """Gets the archived of this Edge.  # noqa: E501


        :return: The archived of this Edge.  # noqa: E501
        :rtype: bool
        """
        return self._archived

    @archived.setter
    def archived(self, archived):
        """Sets the archived of this Edge.


        :param archived: The archived of this Edge.  # noqa: E501
        :type: bool
        """
        if archived is None:
            raise ValueError("Invalid value for `archived`, must not be `None`")  # noqa: E501

        self._archived = archived

    @property
    def created_at(self):
        """Gets the created_at of this Edge.  # noqa: E501


        :return: The created_at of this Edge.  # noqa: E501
        :rtype: str
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this Edge.


        :param created_at: The created_at of this Edge.  # noqa: E501
        :type: str
        """
        if created_at is None:
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    @property
    def modified_at(self):
        """Gets the modified_at of this Edge.  # noqa: E501


        :return: The modified_at of this Edge.  # noqa: E501
        :rtype: str
        """
        return self._modified_at

    @modified_at.setter
    def modified_at(self, modified_at):
        """Sets the modified_at of this Edge.


        :param modified_at: The modified_at of this Edge.  # noqa: E501
        :type: str
        """

        self._modified_at = modified_at

    @property
    def original_data_id(self):
        """Gets the original_data_id of this Edge.  # noqa: E501


        :return: The original_data_id of this Edge.  # noqa: E501
        :rtype: str
        """
        return self._original_data_id

    @original_data_id.setter
    def original_data_id(self, original_data_id):
        """Sets the original_data_id of this Edge.


        :param original_data_id: The original_data_id of this Edge.  # noqa: E501
        :type: str
        """

        self._original_data_id = original_data_id

    @property
    def data_source_id(self):
        """Gets the data_source_id of this Edge.  # noqa: E501


        :return: The data_source_id of this Edge.  # noqa: E501
        :rtype: str
        """
        return self._data_source_id

    @data_source_id.setter
    def data_source_id(self, data_source_id):
        """Sets the data_source_id of this Edge.


        :param data_source_id: The data_source_id of this Edge.  # noqa: E501
        :type: str
        """
        if data_source_id is None:
            raise ValueError("Invalid value for `data_source_id`, must not be `None`")  # noqa: E501

        self._data_source_id = data_source_id

    @property
    def origin_node_original_id(self):
        """Gets the origin_node_original_id of this Edge.  # noqa: E501


        :return: The origin_node_original_id of this Edge.  # noqa: E501
        :rtype: str
        """
        return self._origin_node_original_id

    @origin_node_original_id.setter
    def origin_node_original_id(self, origin_node_original_id):
        """Sets the origin_node_original_id of this Edge.


        :param origin_node_original_id: The origin_node_original_id of this Edge.  # noqa: E501
        :type: str
        """
        if origin_node_original_id is None:
            raise ValueError("Invalid value for `origin_node_original_id`, must not be `None`")  # noqa: E501

        self._origin_node_original_id = origin_node_original_id

    @property
    def destination_node_original_id(self):
        """Gets the destination_node_original_id of this Edge.  # noqa: E501


        :return: The destination_node_original_id of this Edge.  # noqa: E501
        :rtype: str
        """
        return self._destination_node_original_id

    @destination_node_original_id.setter
    def destination_node_original_id(self, destination_node_original_id):
        """Sets the destination_node_original_id of this Edge.


        :param destination_node_original_id: The destination_node_original_id of this Edge.  # noqa: E501
        :type: str
        """
        if destination_node_original_id is None:
            raise ValueError("Invalid value for `destination_node_original_id`, must not be `None`")  # noqa: E501

        self._destination_node_original_id = destination_node_original_id

    @property
    def deleted_at(self):
        """Gets the deleted_at of this Edge.  # noqa: E501


        :return: The deleted_at of this Edge.  # noqa: E501
        :rtype: str
        """
        return self._deleted_at

    @deleted_at.setter
    def deleted_at(self, deleted_at):
        """Sets the deleted_at of this Edge.


        :param deleted_at: The deleted_at of this Edge.  # noqa: E501
        :type: str
        """

        self._deleted_at = deleted_at

    @property
    def data_staging_id(self):
        """Gets the data_staging_id of this Edge.  # noqa: E501


        :return: The data_staging_id of this Edge.  # noqa: E501
        :rtype: float
        """
        return self._data_staging_id

    @data_staging_id.setter
    def data_staging_id(self, data_staging_id):
        """Sets the data_staging_id of this Edge.


        :param data_staging_id: The data_staging_id of this Edge.  # noqa: E501
        :type: float
        """
        if data_staging_id is None:
            raise ValueError("Invalid value for `data_staging_id`, must not be `None`")  # noqa: E501

        self._data_staging_id = data_staging_id

    @property
    def import_data_id(self):
        """Gets the import_data_id of this Edge.  # noqa: E501


        :return: The import_data_id of this Edge.  # noqa: E501
        :rtype: str
        """
        return self._import_data_id

    @import_data_id.setter
    def import_data_id(self, import_data_id):
        """Sets the import_data_id of this Edge.


        :param import_data_id: The import_data_id of this Edge.  # noqa: E501
        :type: str
        """
        if import_data_id is None:
            raise ValueError("Invalid value for `import_data_id`, must not be `None`")  # noqa: E501

        self._import_data_id = import_data_id

    @property
    def type_mapping_transformation_id(self):
        """Gets the type_mapping_transformation_id of this Edge.  # noqa: E501


        :return: The type_mapping_transformation_id of this Edge.  # noqa: E501
        :rtype: str
        """
        return self._type_mapping_transformation_id

    @type_mapping_transformation_id.setter
    def type_mapping_transformation_id(self, type_mapping_transformation_id):
        """Sets the type_mapping_transformation_id of this Edge.


        :param type_mapping_transformation_id: The type_mapping_transformation_id of this Edge.  # noqa: E501
        :type: str
        """
        if type_mapping_transformation_id is None:
            raise ValueError("Invalid value for `type_mapping_transformation_id`, must not be `None`")  # noqa: E501

        self._type_mapping_transformation_id = type_mapping_transformation_id

    @property
    def composite_original_id(self):
        """Gets the composite_original_id of this Edge.  # noqa: E501


        :return: The composite_original_id of this Edge.  # noqa: E501
        :rtype: object
        """
        return self._composite_original_id

    @composite_original_id.setter
    def composite_original_id(self, composite_original_id):
        """Sets the composite_original_id of this Edge.


        :param composite_original_id: The composite_original_id of this Edge.  # noqa: E501
        :type: object
        """

        self._composite_original_id = composite_original_id

    @property
    def origin_node_composite_original_id(self):
        """Gets the origin_node_composite_original_id of this Edge.  # noqa: E501


        :return: The origin_node_composite_original_id of this Edge.  # noqa: E501
        :rtype: str
        """
        return self._origin_node_composite_original_id

    @origin_node_composite_original_id.setter
    def origin_node_composite_original_id(self, origin_node_composite_original_id):
        """Sets the origin_node_composite_original_id of this Edge.


        :param origin_node_composite_original_id: The origin_node_composite_original_id of this Edge.  # noqa: E501
        :type: str
        """
        if origin_node_composite_original_id is None:
            raise ValueError("Invalid value for `origin_node_composite_original_id`, must not be `None`")  # noqa: E501

        self._origin_node_composite_original_id = origin_node_composite_original_id

    @property
    def destination_node_composite_original_id(self):
        """Gets the destination_node_composite_original_id of this Edge.  # noqa: E501


        :return: The destination_node_composite_original_id of this Edge.  # noqa: E501
        :rtype: str
        """
        return self._destination_node_composite_original_id

    @destination_node_composite_original_id.setter
    def destination_node_composite_original_id(self, destination_node_composite_original_id):
        """Sets the destination_node_composite_original_id of this Edge.


        :param destination_node_composite_original_id: The destination_node_composite_original_id of this Edge.  # noqa: E501
        :type: str
        """
        if destination_node_composite_original_id is None:
            raise ValueError("Invalid value for `destination_node_composite_original_id`, must not be `None`")  # noqa: E501

        self._destination_node_composite_original_id = destination_node_composite_original_id

    @property
    def created_by(self):
        """Gets the created_by of this Edge.  # noqa: E501


        :return: The created_by of this Edge.  # noqa: E501
        :rtype: str
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this Edge.


        :param created_by: The created_by of this Edge.  # noqa: E501
        :type: str
        """
        if created_by is None:
            raise ValueError("Invalid value for `created_by`, must not be `None`")  # noqa: E501

        self._created_by = created_by

    @property
    def modified_by(self):
        """Gets the modified_by of this Edge.  # noqa: E501


        :return: The modified_by of this Edge.  # noqa: E501
        :rtype: str
        """
        return self._modified_by

    @modified_by.setter
    def modified_by(self, modified_by):
        """Sets the modified_by of this Edge.


        :param modified_by: The modified_by of this Edge.  # noqa: E501
        :type: str
        """
        if modified_by is None:
            raise ValueError("Invalid value for `modified_by`, must not be `None`")  # noqa: E501

        self._modified_by = modified_by

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Edge, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Edge):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Deep Lynx

    The construction of megaprojects has consistently demonstrated challenges for project managers in regard to meeting cost, schedule, and performance requirements. Megaproject construction challenges are common place within megaprojects with many active projects in the United States failing to meet cost and schedule efforts by significant margins. Currently, engineering teams operate in siloed tools and disparate teams where connections across design, procurement, and construction systems are translated manually or over brittle point-to-point integrations. The manual nature of data exchange increases the risk of silent errors in the reactor design, with each silent error cascading across the design. These cascading errors lead to uncontrollable risk during construction, resulting in significant delays and cost overruns. Deep Lynx allows for an integrated platform during design and operations of mega projects.  The Deep Lynx Core API delivers a few main features.  1. Provides a set of methods and endpoints for manipulating data in an object oriented database. This allows us to store complex datatypes as records and then to compile them into actual, modifiable objects at run-time. Users can store taxonomies or ontologies in a readable format.  2. Provides methods for storing and retrieving data in a graph database. This data is structured and validated against the aformentioned object oriented database before storage.  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from swagger_client.api_client import ApiClient


class ContainersApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def archive_container(self, container_id, **kwargs):  # noqa: E501
        """ArchiveContainer  # noqa: E501

        Archives a Container. This is preferred over deletion as deletion has a cascading effect on the deleted type's keys, relationships, and relationship keys. When in doubt, archive over delete. We'd rather have tombstones than cremating the type.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.archive_container(container_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container_id: (required)
        :param bool permanent: If true, permanently deletes the container
        :return: Generic200Response
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.archive_container_with_http_info(container_id, **kwargs)  # noqa: E501
        else:
            (data) = self.archive_container_with_http_info(container_id, **kwargs)  # noqa: E501
            return data

    def archive_container_with_http_info(self, container_id, **kwargs):  # noqa: E501
        """ArchiveContainer  # noqa: E501

        Archives a Container. This is preferred over deletion as deletion has a cascading effect on the deleted type's keys, relationships, and relationship keys. When in doubt, archive over delete. We'd rather have tombstones than cremating the type.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.archive_container_with_http_info(container_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container_id: (required)
        :param bool permanent: If true, permanently deletes the container
        :return: Generic200Response
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['container_id', 'permanent']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method archive_container" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'container_id' is set
        if ('container_id' not in params or
                params['container_id'] is None):
            raise ValueError("Missing the required parameter `container_id` when calling `archive_container`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'container_id' in params:
            path_params['container_id'] = params['container_id']  # noqa: E501

        query_params = []
        if 'permanent' in params:
            query_params.append(('permanent', params['permanent']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['httpBearer']  # noqa: E501

        return self.api_client.call_api(
            '/containers/{container_id}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Generic200Response',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def container_batch_update(self, body, **kwargs):  # noqa: E501
        """ContainerBatchUpdate  # noqa: E501

        Accepts an array of container objects - will attempt to update all of them in a single transaction. If the update fails, none of them will go through.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.container_batch_update(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[BatchContainerUpdateRequest] body: (required)
        :return: BatchUpdateContainerResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.container_batch_update_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.container_batch_update_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def container_batch_update_with_http_info(self, body, **kwargs):  # noqa: E501
        """ContainerBatchUpdate  # noqa: E501

        Accepts an array of container objects - will attempt to update all of them in a single transaction. If the update fails, none of them will go through.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.container_batch_update_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[BatchContainerUpdateRequest] body: (required)
        :return: BatchUpdateContainerResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method container_batch_update" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `container_batch_update`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['httpBearer']  # noqa: E501

        return self.api_client.call_api(
            '/containers', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BatchUpdateContainerResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_container(self, body, **kwargs):  # noqa: E501
        """CreateContainer  # noqa: E501

        Creates a new container object. Containers are the root level object and are considered to contain both the ontology(in form of Metatypes, Metatype Keys, and MetatypeRelationships) as well as the data stored under that ontology.  Endpoint will accept both a single container request object, or an array of container request objects  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_container(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateContainerRequest body: (required)
        :return: CreateContainerResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_container_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.create_container_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def create_container_with_http_info(self, body, **kwargs):  # noqa: E501
        """CreateContainer  # noqa: E501

        Creates a new container object. Containers are the root level object and are considered to contain both the ontology(in form of Metatypes, Metatype Keys, and MetatypeRelationships) as well as the data stored under that ontology.  Endpoint will accept both a single container request object, or an array of container request objects  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_container_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateContainerRequest body: (required)
        :return: CreateContainerResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_container" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `create_container`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['httpBearer']  # noqa: E501

        return self.api_client.call_api(
            '/containers', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CreateContainerResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def import_container(self, **kwargs):  # noqa: E501
        """ImportContainer  # noqa: E501

        An optional query param `dryrun` may be included with a value of `true` in order to return a HTML formatted string explaining the name and description of the container along with the number of metatypes, metatype relationships, and metatype keys to be created. This request uses a form-data body. If the ontology to be imported is being referenced via url, provide the url via a `path` field. Otherwise a local file may be provided. A file takes precedence over a `path` value if both are provided.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.import_container(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str name:
        :param str description:
        :param bool data_versioning_enabled:
        :param str path:
        :param str file:
        :param bool dryrun: If true returns a description of the container that will be created and its contents.
        :return: ContainerImportResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.import_container_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.import_container_with_http_info(**kwargs)  # noqa: E501
            return data

    def import_container_with_http_info(self, **kwargs):  # noqa: E501
        """ImportContainer  # noqa: E501

        An optional query param `dryrun` may be included with a value of `true` in order to return a HTML formatted string explaining the name and description of the container along with the number of metatypes, metatype relationships, and metatype keys to be created. This request uses a form-data body. If the ontology to be imported is being referenced via url, provide the url via a `path` field. Otherwise a local file may be provided. A file takes precedence over a `path` value if both are provided.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.import_container_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str name:
        :param str description:
        :param bool data_versioning_enabled:
        :param str path:
        :param str file:
        :param bool dryrun: If true returns a description of the container that will be created and its contents.
        :return: ContainerImportResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['name', 'description', 'data_versioning_enabled', 'path', 'file', 'dryrun']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method import_container" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'dryrun' in params:
            query_params.append(('dryrun', params['dryrun']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}
        if 'name' in params:
            form_params.append(('name', params['name']))  # noqa: E501
        if 'description' in params:
            form_params.append(('description', params['description']))  # noqa: E501
        if 'data_versioning_enabled' in params:
            form_params.append(('data_versioning_enabled', params['data_versioning_enabled']))  # noqa: E501
        if 'path' in params:
            form_params.append(('path', params['path']))  # noqa: E501
        if 'file' in params:
            form_params.append(('file', params['file']))  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/x-www-form-urlencoded'])  # noqa: E501

        # Authentication setting
        auth_settings = ['httpBearer']  # noqa: E501

        return self.api_client.call_api(
            '/containers/import', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ContainerImportResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_containers(self, **kwargs):  # noqa: E501
        """ListContainers  # noqa: E501

        List all containers.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_containers(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: ListContainerResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.list_containers_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.list_containers_with_http_info(**kwargs)  # noqa: E501
            return data

    def list_containers_with_http_info(self, **kwargs):  # noqa: E501
        """ListContainers  # noqa: E501

        List all containers.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_containers_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: ListContainerResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_containers" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['httpBearer']  # noqa: E501

        return self.api_client.call_api(
            '/containers', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ListContainerResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def repair_container_permissions(self, container_id, **kwargs):  # noqa: E501
        """RepairContainerPermissions  # noqa: E501

        Repairs a container's permission set  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.repair_container_permissions(container_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container_id: (required)
        :return: Generic200Response
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.repair_container_permissions_with_http_info(container_id, **kwargs)  # noqa: E501
        else:
            (data) = self.repair_container_permissions_with_http_info(container_id, **kwargs)  # noqa: E501
            return data

    def repair_container_permissions_with_http_info(self, container_id, **kwargs):  # noqa: E501
        """RepairContainerPermissions  # noqa: E501

        Repairs a container's permission set  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.repair_container_permissions_with_http_info(container_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container_id: (required)
        :return: Generic200Response
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['container_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method repair_container_permissions" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'container_id' is set
        if ('container_id' not in params or
                params['container_id'] is None):
            raise ValueError("Missing the required parameter `container_id` when calling `repair_container_permissions`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'container_id' in params:
            path_params['container_id'] = params['container_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['httpBearer']  # noqa: E501

        return self.api_client.call_api(
            '/containers/{container_id}/permissions', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Generic200Response',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def retrieve_container(self, container_id, **kwargs):  # noqa: E501
        """RetrieveContainer  # noqa: E501

        Retrieve container by ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.retrieve_container(container_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container_id: (required)
        :return: GetContainerResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.retrieve_container_with_http_info(container_id, **kwargs)  # noqa: E501
        else:
            (data) = self.retrieve_container_with_http_info(container_id, **kwargs)  # noqa: E501
            return data

    def retrieve_container_with_http_info(self, container_id, **kwargs):  # noqa: E501
        """RetrieveContainer  # noqa: E501

        Retrieve container by ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.retrieve_container_with_http_info(container_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container_id: (required)
        :return: GetContainerResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['container_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method retrieve_container" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'container_id' is set
        if ('container_id' not in params or
                params['container_id'] is None):
            raise ValueError("Missing the required parameter `container_id` when calling `retrieve_container`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'container_id' in params:
            path_params['container_id'] = params['container_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['httpBearer']  # noqa: E501

        return self.api_client.call_api(
            '/containers/{container_id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetContainerResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def set_container_active(self, container_id, **kwargs):  # noqa: E501
        """SetContainerActive  # noqa: E501

        Unarchives a Container. This is the only way to update this value of a container via API.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.set_container_active(container_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container_id: (required)
        :return: Generic200Response
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.set_container_active_with_http_info(container_id, **kwargs)  # noqa: E501
        else:
            (data) = self.set_container_active_with_http_info(container_id, **kwargs)  # noqa: E501
            return data

    def set_container_active_with_http_info(self, container_id, **kwargs):  # noqa: E501
        """SetContainerActive  # noqa: E501

        Unarchives a Container. This is the only way to update this value of a container via API.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.set_container_active_with_http_info(container_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container_id: (required)
        :return: Generic200Response
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['container_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method set_container_active" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'container_id' is set
        if ('container_id' not in params or
                params['container_id'] is None):
            raise ValueError("Missing the required parameter `container_id` when calling `set_container_active`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'container_id' in params:
            path_params['container_id'] = params['container_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['httpBearer']  # noqa: E501

        return self.api_client.call_api(
            '/containers/{container_id}/active', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Generic200Response',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_container(self, body, container_id, **kwargs):  # noqa: E501
        """UpdateContainer  # noqa: E501

        Updates the container. This will fail if a container already exists with the proposed updated name.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_container(body, container_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UpdateContainerRequest body: (required)
        :param str container_id: (required)
        :return: UpdateContainerResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_container_with_http_info(body, container_id, **kwargs)  # noqa: E501
        else:
            (data) = self.update_container_with_http_info(body, container_id, **kwargs)  # noqa: E501
            return data

    def update_container_with_http_info(self, body, container_id, **kwargs):  # noqa: E501
        """UpdateContainer  # noqa: E501

        Updates the container. This will fail if a container already exists with the proposed updated name.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_container_with_http_info(body, container_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UpdateContainerRequest body: (required)
        :param str container_id: (required)
        :return: UpdateContainerResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'container_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_container" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `update_container`")  # noqa: E501
        # verify the required parameter 'container_id' is set
        if ('container_id' not in params or
                params['container_id'] is None):
            raise ValueError("Missing the required parameter `container_id` when calling `update_container`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'container_id' in params:
            path_params['container_id'] = params['container_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['httpBearer']  # noqa: E501

        return self.api_client.call_api(
            '/containers/{container_id}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UpdateContainerResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_container_import(self, container_id, **kwargs):  # noqa: E501
        """UpdateContainerImport  # noqa: E501

        Updates an existing container via an ontology file.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_container_import(container_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container_id: (required)
        :param str name:
        :param str description:
        :param bool data_versioning_enabled:
        :param str path:
        :param str file:
        :return: ContainerImportUpdateResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_container_import_with_http_info(container_id, **kwargs)  # noqa: E501
        else:
            (data) = self.update_container_import_with_http_info(container_id, **kwargs)  # noqa: E501
            return data

    def update_container_import_with_http_info(self, container_id, **kwargs):  # noqa: E501
        """UpdateContainerImport  # noqa: E501

        Updates an existing container via an ontology file.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_container_import_with_http_info(container_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container_id: (required)
        :param str name:
        :param str description:
        :param bool data_versioning_enabled:
        :param str path:
        :param str file:
        :return: ContainerImportUpdateResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['container_id', 'name', 'description', 'data_versioning_enabled', 'path', 'file']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_container_import" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'container_id' is set
        if ('container_id' not in params or
                params['container_id'] is None):
            raise ValueError("Missing the required parameter `container_id` when calling `update_container_import`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'container_id' in params:
            path_params['container_id'] = params['container_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}
        if 'name' in params:
            form_params.append(('name', params['name']))  # noqa: E501
        if 'description' in params:
            form_params.append(('description', params['description']))  # noqa: E501
        if 'data_versioning_enabled' in params:
            form_params.append(('data_versioning_enabled', params['data_versioning_enabled']))  # noqa: E501
        if 'path' in params:
            form_params.append(('path', params['path']))  # noqa: E501
        if 'file' in params:
            form_params.append(('file', params['file']))  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/x-www-form-urlencoded'])  # noqa: E501

        # Authentication setting
        auth_settings = ['httpBearer']  # noqa: E501

        return self.api_client.call_api(
            '/containers/import/{container_id}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ContainerImportUpdateResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)
